#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SPLIT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SPLIT_HPP_INCLUDED

#include <boost/simd/swar/include/functions/split.hpp>

#endif
